Buy Light Bulbs from the Web's #1 Lighting Retailer | 1000Bulbs.com
Description: America's Largest Online Light Bulb Retailer! Thousands of Halogens, CFLs, Automotive Bulbs, Christmas Lights, LEDs, Rope Lights, and Electrical Supplies.
Keywords: Light bulbs, halogen lightbulbs, rope lights, christmas lights, ballasts, fluorescent bulbs

For expert help, call: 1-800-624-4488

Don't have an account? Signup

#### Login

Email Password Remember Me

Forgot Password?

Product Search

For expert help, call: 1-800-624-4488

##### LED Antique Filament Bulbs

##### Hydroponic Supplies

##### LED Panels & Troffers

##### Top Light Bulb Categories

- Standard Shape LED Bulbs

- Christmas

- Halogen Bulbs

- Compact Fluorescents

- Incandescent Bulbs

- Rope Light

##### Featured Products (19)

LED - 9W - A19 - 60W Equal - 2700K Warm White
Brand: Curtis Mathes
$2.99
(7)
An error has occurred
Checkout
Quantity
Must be a number
Dimmable LED - 12 Watt - R30 - 60W Equal - 700 Lumens
Brand: Kobi
$6.99
(58)
An error has occurred
Checkout
Quantity
Must be a number
24 ft. Stringer - (70) Wide Angle LEDs - WARM WHITE - 4 in.
Brand: HLS
$13.99
(13)
An error has occurred
Checkout
Quantity
Must be a number
25 ft. Stringer - (50) LED Laser Tip Warm White Bulbs
Brand: HLS
$9.73
(2)
An error has occurred
Checkout
Quantity
Must be a number
25 ft. Stringer - (50) LED Laser Tip Cool White Bulbs
Brand: HLS
$11.99
An error has occurred
Checkout
Quantity
Must be a number
1650 Lumens - LED - 4 ft. Tube - 13 Watt - 4100K Cool White
Brand: LifeBulb
$9.99
(19)
An error has occurred
Checkout
Quantity
Must be a number
LED - BR30 Flood - 6 Watt - 65W Equal - 2700K Warm White - 6
Brand: LifeBulb
$7.99
An error has occurred
Checkout
Quantity
Must be a number
Dimmable LED - 19 Watt - A21 - 100 Watt Equal - 1600 Lumens
Brand: SYLVANIA
$10.99
An error has occurred
Checkout
Quantity
Must be a number
2 x 4 Dimmable LED Troffer - 4200 Lumens - 4000 Kelvin
Brand: Energetic Lighting
$99.99
(1)
An error has occurred
Checkout
Quantity
Must be a number
14 Watt - CFL - 60 W Equal - 2700K Warm White - 4 Pack
Brand: PLT
$4.20
(36)
An error has occurred
Checkout
Quantity
Must be a number
60 Watt - Vintage Antique Light Bulb - 1910 Edison Style - 4
Brand: Antique Light Bulb Co.
$3.50
(77)
An error has occurred
Checkout
Quantity
Must be a number
LED - Filament Type - 3.5W - ST19 Edison Style - 60W Equal
Brand: PLT
$13.49
(9)
An error has occurred
Checkout
Quantity
Must be a number
LED - Filament Type - 3W - ST45 - 40W Equal - 2200K
Brand: PLT
$7.99
(1)
An error has occurred
Checkout
Quantity
Must be a number
38 Watt - PAR20 - 50W Equal - Flood - Halogen - 1,500 Hours
Brand: Plusrite
$2.25
(38)
An error has occurred
Checkout
Quantity
Must be a number
LED - 7.5W - MR16 - 50W Equal - Flood - 435 Lumens - 3000K
Brand: Soraa
$23.93
(1)
An error has occurred
Checkout
Quantity
Must be a number
48 ft. Patio Light Stringer - (15) Suspended Sockets - Black
Brand: PLT
$74.99
(20)
An error has occurred
Checkout
Quantity
Must be a number
37 Watt - LED - Wall Pack - 165W Equal - 3000 Lumens
Brand: AC Electronics
$119.99
(7)
An error has occurred
Checkout
Quantity
Must be a number
36 Watt - LED - Wall Pack - 150W Equal - 3300 Lumens - 4000K
Brand: PLT
$124.99
(3)
Sold Out
1/2 in. - Incandescent - Warm White - Rope Light - 2 Wire
Brand:
$59.95
(3)
An error has occurred
Checkout
Quantity
Must be a number